@@ -2,12 +2,11 @@ import numbers
 import os
 import os.path
 import re
-from typing import List, Dict, overload
-from pprint import pformat
+from typing import List
 
 from dbrecord import PDict
 from datetime import datetime
-from operator import gt, ge, le, lt, eq, ne
+from operator import gt, ge, le, lt
 
 from lumo.proc.path import progressroot, exproot, dbroot, cache_dir
 from .experiment import Experiment
@@ -34,6 +33,20 @@ styles = {
 }
 
 
+def eq(ser, value):
+    if value is None:
+        return ser.isna() == True
+    else:
+        return ser == value
+
+
+def ne(ser, value):
+    if value is None:
+        return ser.isna() == False
+    else:
+        return ser != value
+
+
 def in_(ser, value):
     """pandas operation"""
     return ser.apply(lambda x: x in value)
@@ -231,7 +244,7 @@ class Condition:
             if isinstance(value, pd.DataFrame):
                 value = value[i]
             else:
-                value = value.apply(lambda x: x[i])
+                value = value.apply(lambda x: x.get(i) if isinstance(x, dict) else None)
         return mapping[self.op](value, self.value)
 
     def capply(self, df):
@@ -257,7 +270,7 @@ class Condition:
                     if isinstance(value, pd.DataFrame):
                         value = value[i]
                     else:
-                        value = value.apply(lambda x: x[i])
+                        value = value.apply(lambda x: x.get(i) if isinstance(x, dict) else None)
                 df[aim] = value
         return df
 
@@ -483,8 +496,11 @@ def is_test_root(path: str) -> bool:
     Returns:
         True if the path is a valid test root, False otherwise.
     """
-    test_name = os.path.basename(path.rstrip('/'))
-    return is_test_name(test_name)
+    if os.path.exists(os.path.join(path, 'info', 'test_name.json')):
+        return True
+
+    # test_name = os.path.basename(path.rstrip('/'))
+    # return is_test_name(test_name)
 
 
 def is_test_name(test_name: str) -> bool:
